.. :changelog:

History
-------

0.4.1 (2024-12-06)
++++++++++++++++++

**Fix:** dict2rec with 2D parameter

0.4.0 (2024-10-17)
++++++++++++++++++

**New feature:**

* rec2pd for recarrays that have a 2D parameter

0.3.1 (2024-07-31)
++++++++++++++++++

**Fixes:**

* added some necessary defaults
* fixed dependencies

0.3.0 (2024-03-27)
++++++++++++++++++

**New feature:**

* use copy_guardian for copying

0.2.0 (2024-01-24)
++++++++++++++++++

**New features:**

* new arraytools functions for recarray conversions, nan handling, writing to
  file, and more

* new functions to write to and load from files in file_utils

* parsing functions and other utils


0.1.1 (2023-04-26)
++++++++++++++++++

**Fix:** dependencies

0.1.0 (2023-04-26)
++++++++++++++++++

* First release on PyPI.
